"""
This module contains default configuration of the core 'plugin'.

The config object `c` is relatively imported, and options under the `core`
attribute is set to the default values. It's encouraged for plugin developer to
use this way for plugin options.

DO NOT EDIT THIS FILE, copy lines into `instance/config.py` to override.
"""
from whisper.core import app, require
from . import InfimumTheme as provider  # pylint: disable=unused-import

require('core')
require('file')
require('markdown')

app.c.infimum.page_size = 10

app.c.infimum.navs = []
# Exmaple:
# app.c.infimum.navs = [
#     {
#         'name': 'About',
#         'href': '/about/',
#         'attr': 'target="_blank"',
#     },
# ]

app.c.infimum.widgets = [
    {
        'title': 'Welcome to Infimum',
        'html': '<p>You may customize widgets by configuring'
                '<code>app.c.infimum.widgets</code>.</p>',
    },
]

app.c.infimum.footer = """
<p>
Proudly powered by
<a target="_blank" href="https://github.com/TechCiel/whisper">Whisper</a>,
theme
<a target="_blank" href="https://github.com/TechCiel/whisper/tree/infimum">Infimum</a>.
</p>
"""
