/*! normalize.css v8.0.1 | MIT License | github.com/necolas/normalize.css */
html{line-height:1.15;-webkit-text-size-adjust:100%}body{margin:0}main{display:block}h1{font-size:2em;margin:.67em 0}hr{-webkit-box-sizing:content-box;box-sizing:content-box;height:0;overflow:visible}pre{font-family:monospace,monospace;font-size:1em}a{background-color:transparent}abbr[title]{border-bottom:none;text-decoration:underline;-webkit-text-decoration:underline dotted;text-decoration:underline dotted}b,strong{font-weight:bolder}code,kbd,samp{font-family:monospace,monospace;font-size:1em}small{font-size:80%}sub,sup{font-size:75%;line-height:0;position:relative;vertical-align:baseline}sub{bottom:-.25em}sup{top:-.5em}img{border-style:none}button,input,optgroup,select,textarea{font-family:inherit;font-size:100%;line-height:1.15;margin:0}button,input{overflow:visible}button,select{text-transform:none}[type=button],[type=reset],[type=submit],button{-webkit-appearance:button}[type=button]::-moz-focus-inner,[type=reset]::-moz-focus-inner,[type=submit]::-moz-focus-inner,button::-moz-focus-inner{border-style:none;padding:0}[type=button]:-moz-focusring,[type=reset]:-moz-focusring,[type=submit]:-moz-focusring,button:-moz-focusring{outline:1px dotted ButtonText}fieldset{padding:.35em .75em .625em}legend{-webkit-box-sizing:border-box;box-sizing:border-box;color:inherit;display:table;max-width:100%;padding:0;white-space:normal}progress{vertical-align:baseline}textarea{overflow:auto}[type=checkbox],[type=radio]{-webkit-box-sizing:border-box;box-sizing:border-box;padding:0}[type=number]::-webkit-inner-spin-button,[type=number]::-webkit-outer-spin-button{height:auto}[type=search]{-webkit-appearance:textfield;outline-offset:-2px}[type=search]::-webkit-search-decoration{-webkit-appearance:none}::-webkit-file-upload-button{-webkit-appearance:button;font:inherit}details{display:block}summary{display:list-item}template{display:none}[hidden]{display:none}

:root {
    --bg: #eee;
    --fg: #000;
    --link: #06f;
}

@media screen and (prefers-color-scheme: dark) {
    :root {
        --bg: #222;
        --fg: #eee;
        --link: #39f;
    }
}

* {
    box-sizing: border-box;
}

body {
    padding: 1em 20%;
    color: var(--fg);
    background-color: var(--bg);
    font-family: "Open Sans", Helvetica, Arial, sans-serif;
}

a {
    color: var(--link);
    text-decoration: none;
}

a:hover {
    text-decoration: underline;
}

a[disabled] {
    color: var(--fg);
    pointer-events: none;
    cursor: text;
    text-decoration: none;
}

hr {
    margin: 0;
}

select,
input[type="text"],
input[type="password"],
input[type="search"],
textarea {
    background-color: var(--bg);
    border: var(--fg) 1px solid;
    border-radius: 2px;
    color: var(--fg);
    line-height: 1.2em;
    padding: 0.2em;
}

textarea {
    width: 100%;
    height: 100%;
    resize: vertical;
}

button {
    cursor: pointer;
    user-select: none;
    padding: 0.5em 1em;
    border: none;
    background-color: #339;
    color: white;
}

details {
    border: 1px solid #9999;
    border-radius: 2px;
    padding: 0.5em;
    margin: 1em 0;
}


details summary {
    cursor: pointer;
    user-select: none;
    font-weight: bold;
}

details[open] summary {
    margin-bottom: 1em
}

table {
    width: 100%;
    border-collapse: collapse;
    line-height: 1.5em;
    text-align: left;
    overflow-x: auto;
}

table tr {
    vertical-align: top;
}

table tr>* {
    padding: 0.5em;
}

table th {
    border-bottom: solid 2px;
}

table td {
    border-bottom: #bbb7 solid 1px;
}

body {
    display: flex;
    flex-direction: column;
    min-height: 100vh;
}


header {
    display: flex;
    flex-wrap: wrap;
    align-items: center;
}

header > p {
    flex: 999 content;
    font-family: 'Times New Roman', Times, serif;
    font-size: 2em;
    margin: 0.5em 0;
}

header > p > a {
    color: var(--fg);
}

header > a {
    flex: 1 content;
    margin: 0.5em;
    color: var(--fg);
}

main {
    flex: 999;
    display: flex;
    width: 100%;
    margin: 1em 0;
}

main > article,
main > div#list {
    flex: 5 70%;
}

main > aside {
    flex: 2 25%;
    margin-top: -1em;
    margin-left: 1em;
}

main > aside > h3 {
    margin-bottom: 0.5em;
}

footer {
    font-style: italic;
}
@media screen and (max-width: 1920px) {
    body {
        padding-left: 10%;
        padding-right: 10%;
    }
}

@media screen and (max-width: 1024px) {
    body {
        padding-left: 5%;
        padding-right: 5%;
    }
}

@media screen and (max-width: 768px) {
    body {
        padding-left: 5%;
        padding-right: 5%;
    }

    main {
        flex-wrap: wrap;
    }

    main aside {
        margin: 0;
    }
}

@media screen and (max-width: 568px) {
    body {
        padding-left: 1em;
        padding-right: 1em;
    }
}
